==> eiffelstudio-18.01.10.1424.tar: F_code/C39/ds1903.c <==
/*
 * Code for class DS_SHELL_SORTER [INTEGER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ds1903.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DS_SHELL_SORTER}.subsort_with_comparator */
void F87_962 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg3 < arg4)) {
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (arg4 - arg3) + ((EIF_INTEGER_32) 1L)) / ((EIF_INTEGER_32) 2L));
		for (;;) {
			if ((EIF_BOOLEAN) (loc4 <= ((EIF_INTEGER_32) 0L))) break;
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg3 + loc4);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > arg4)) break;
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 - loc4);
				for (;;) {
					if ((EIF_BOOLEAN) (loc2 < arg3)) break;
					loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + loc4);
					loc5 = F1404_13543(RTCW(arg1), loc2);
					loc6 = F1404_13543(RTCW(arg1), loc3);
					tb1 = F503_3153(RTCW(arg2), loc6, loc5);
					if (tb1) {
						F1404_13554(RTCW(arg1), loc6, loc2);
						F1404_13554(RTCW(arg1), loc5, loc3);
						loc2 -= loc4;
					} else {
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg3 - ((EIF_INTEGER_32) 1L));
					}
				}
				loc1++;
			}
			loc4 /= ((EIF_INTEGER_32) 2L);
		}
	}
	RTLE;
}

void EIF_Minit1903 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C39/ds1903.c <==
/*
 * Code for class DS_SHELL_SORTER [INTEGER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ds1903.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DS_SHELL_SORTER}.subsort_with_comparator */
void F105_1222 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg3 < arg4)) {
		loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (arg4 - arg3) + ((EIF_INTEGER_32) 1L)) / ((EIF_INTEGER_32) 2L));
		for (;;) {
			if ((EIF_BOOLEAN) (loc4 <= ((EIF_INTEGER_32) 0L))) break;
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg3 + loc4);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > arg4)) break;
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 - loc4);
				for (;;) {
					if ((EIF_BOOLEAN) (loc2 < arg3)) break;
					loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + loc4);
					loc5 = *(EIF_INTEGER_32 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R10752[Dtype(arg1)-1408])(RTCW(arg1), loc2));
					loc6 = *(EIF_INTEGER_32 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R10752[Dtype(arg1)-1408])(RTCW(arg1), loc3));
					tb1 = F334_3148(RTCW(arg2), loc6, loc5);
					if (tb1) {
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R10759[Dtype(arg1)-1408])(RTCW(arg1), (EIF_REFERENCE) &loc6, loc2);
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R10759[Dtype(arg1)-1408])(RTCW(arg1), (EIF_REFERENCE) &loc5, loc3);
						loc2 -= loc4;
					} else {
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg3 - ((EIF_INTEGER_32) 1L));
					}
				}
				loc1++;
			}
			loc4 /= ((EIF_INTEGER_32) 2L);
		}
	}
	RTLE;
}

void EIF_Minit1903 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
